const ZeedhiAPIConstructor = require('zeedhi-functional-test-api');
const z = new ZeedhiAPIConstructor(browser, protractor);
const Helper = require('teknisa-helper');
const geral = new Helper.geral();
const loginPage = new Helper.login();
const protractorHelper = require('protractor-helper');
const parametrizacaoTituloPage = require('../../../page-objects/parametrizacao/financeiro/parametrizacaoTituloPagar.po');
const j = require('../../../json/leitorJson.po.js');

describe('Tela Parâmetros de Títulos a Pagar', () => {
	beforeAll(() => {
		browser.get('http://erpteste.teknisa.com/login/');
		loginPage.login(j.getValor('login'), j.getValor('senha'));
		parametrizacaoTituloPage.abrir();
		geral.waitFieldVisibility('DSMULTAPAG');
	});

	afterAll(() => {
		geral.sair();
	});

	it('Acessar a tela Parâmetros de Títulos a Pagar', () => {
		expect(z.component.header.getTitle())
			.toBe('Parâmetros de Títulos a Pagar');
	});

	it('Editar os campos de Tipos de Ajuste na Baixa, CNAB, e Antecipação Automática', () => {
		geral.clickEditar();
		parametrizacaoTituloPage.editarAjustes(j.getValor('multa'), j.getValor('mora'),
			j.getValor('desconto'), j.getValor('acrescimo'), j.getValor('desconto1'),
			j.getValor('tipoDeBaixa'));
		geral.clickSalvar();
		geral.waitFieldVisibility('DSMULTAPAG');

		expect(geral.getTextoPorId('DSMULTAPAG'))
			.toBe(j.getValor('multa'));
		expect(geral.getTextoPorId('DSMORAPAG'))
			.toBe(j.getValor('mora'));
		expect(geral.getTextoPorId('DSUANTAUTO'))
			.toBe(j.getValor('desconto'));
		expect(geral.getTextoPorId('DSCREPAG'))
			.toBe(j.getValor('acrescimo'));
	});

	it('Editar os campos de Tipo de Baixa para Transferência Eletrônica, Retorno CNAB a Dados para Geração Financeira', () => {
		geral.clickEditar();
		parametrizacaoTituloPage.editarAjustesTipoBaixa(j.getValor('creditoEmConta'),
			j.getValor('DOC'), j.getValor('TED'), j.getValor('tipoDeCreditoBancario'),
			j.getValor('utilizaHabilitacao'), 'Não', j.getValor('utilizaAutorizacao'),
			j.getValor('utilizaNota'), j.getValor('exibeCalculo'), j.getValor('serie'),
			j.getValor('fornecedor'), j.getValor('tipoOperacao'), j.getValor('tipoConta'));
		geral.clickSalvar();
		geral.waitFieldVisibility('NMBAIXATED');

		expect(geral.getTextoPorId('NMBAIXATED'))
			.toBe(j.getValor('TED'));
		expect(geral.getTextoPorId('NMTIPOOPERSAG'))
			.toBe(j.getValor('tipoOperacao'));
		expect(geral.getTextoPorId('IDUTIAUTDESP'))
			.toBe(j.getValor('utilizaAutorizacao'));
	});

	it('Editar os registros da aba Intervalo de Datas de Parâmetros de Títulos a Pagar', () => {
		const min = 1;
		const max = 999;
		const anteriores = Helper.util.geraInt(min, max);
		const posteriores = Helper.util.geraInt(min, max);
		const anteriores1 = Helper.util.geraInt(min, max);
		const posteriores1 = Helper.util.geraInt(min, max);
		geral.trocarAba('Intervalo de Datas');
		geral.waitFieldVisibility('QTDIAANTBAIP');
		geral.clickEditar();
		parametrizacaoTituloPage.editarIntervalodeDatas(anteriores, posteriores, anteriores1, posteriores1);
		geral.clickSalvar();
		geral.waitFieldVisibility('QTDIAANTBAIP');

		expect(geral.getTextoPorId('QTDIAANTBAIP'))
			.toBe(anteriores);
		expect(geral.getTextoPorId('QTDIAAPOBAIP'))
			.toBe(posteriores);
		expect(geral.getTextoPorId('QTDIAANTBOLP'))
			.toBe(anteriores1);
		expect(geral.getTextoPorId('QTDIAAPOBOLP'))
			.toBe(posteriores1);
	});

	it('Apagar todos campos da aba Operacional', () => {
		geral.clickEditar();
		protractorHelper.waitForElementVisibility(element(by.id('DSMULTAPAG')));
		parametrizacaoTituloPage.apagarCamposOperacional();
		geral.clickSalvar();
		geral.waitFieldVisibility('DSMULTAPAG');

		expect(geral.getTextoPorId('DSMULTAPAG'))
			.toBe('');
		expect(geral.getTextoPorId('DSMORAPAG'))
			.toBe('');
		expect(geral.getTextoPorId('NMCREDCONT'))
			.toBe('');
		expect(geral.getTextoPorId('DSSERIEENTRSAG'))
			.toBe('');
	});

	it('Apagar todos campos da aba Intervalo de Datas', () => {
		geral.trocarAba('Intervalo de Datas');
		geral.clickEditar();
		parametrizacaoTituloPage.apagarCamposIntervaloDatas();
		geral.clickSalvar();
		geral.waitFieldVisibility('QTDIAANTBAIP');

		expect(geral.getTextoPorId('QTDIAANTBAIP'))
			.toBe('0');
		expect(geral.getTextoPorId('QTDIAAPOBAIP'))
			.toBe('0');
		expect(geral.getTextoPorId('QTDIAANTBOLP'))
			.toBe('0');
		expect(geral.getTextoPorId('QTDIAAPOBOLP'))
			.toBe('0');
	});
});
